@@ -27,8 +27,8 @@ sub attach_db {
     my ( $sf ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $cur_attached;
-    if ( -s $sf->{i}{file_attached_db} ) {
-        my $h_ref = $ax->read_json( $sf->{i}{file_attached_db} );
+    if ( -s $sf->{i}{f_attached_db} ) {
+        my $h_ref = $ax->read_json( $sf->{i}{f_attached_db} );
         $cur_attached = $h_ref->{$sf->{d}{db}} || [];
     }
     my $choices = [ undef, @{$sf->{d}{user_dbs}}, @{$sf->{d}{sys_dbs}} ];
@@ -101,9 +101,9 @@ sub attach_db {
                     if ( ! @$new_attached ) {
                         return;
                     }
-                    my $h_ref = $ax->read_json( $sf->{i}{file_attached_db} );
+                    my $h_ref = $ax->read_json( $sf->{i}{f_attached_db} );
                     $h_ref->{$sf->{d}{db}} = [ sort( @$cur_attached, @$new_attached  ) ];
-                    $ax->write_json( $sf->{i}{file_attached_db}, $h_ref );
+                    $ax->write_json( $sf->{i}{f_attached_db}, $h_ref );
                     return 1;
                 }
                 elsif ( $choice eq $more ) {
@@ -119,8 +119,8 @@ sub detach_db {
     my ( $sf ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $attached_db;
-    if ( -s $sf->{i}{file_attached_db} ) {
-        my $h_ref = $ax->read_json( $sf->{i}{file_attached_db} );
+    if ( -s $sf->{i}{f_attached_db} ) {
+        my $h_ref = $ax->read_json( $sf->{i}{f_attached_db} );
         $attached_db = $h_ref->{$sf->{d}{db}} || [];
     }
     my @chosen;
@@ -147,14 +147,14 @@ sub detach_db {
             return;
         }
         elsif ( $idx == $#pre ) {
-            my $h_ref = $ax->read_json( $sf->{i}{file_attached_db} );
+            my $h_ref = $ax->read_json( $sf->{i}{f_attached_db} );
             if ( @$attached_db ) {
                 $h_ref->{$sf->{d}{db}} = $attached_db;
             }
             else {
                 delete $h_ref->{$sf->{d}{db}};
             }
-            $ax->write_json( $sf->{i}{file_attached_db}, $h_ref );
+            $ax->write_json( $sf->{i}{f_attached_db}, $h_ref );
             return 1;
         }
         push @chosen, splice( @$attached_db, $idx - @pre, 1 );
